==> code-highlight-adapter-1.7.2.tgz: package/lib-esm/highlighters/prism-highlighter.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { BaseHighlighter } from './base-highlighter';
import { adaptSql, setAttributes } from './utils';
import { loadCss, loadScript } from '@cnblogs/load-script-css';
import { HighlightedLineToken } from './constants';
var _global = window;
/**
 * @public
 */
var PrismHighlighter = /** @class */ (function (_super) {
    __extends(PrismHighlighter, _super);
    function PrismHighlighter() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._linkAttr = {
            name: 'prismjs',
            value: '',
        };
        return _this;
    }
    Object.defineProperty(PrismHighlighter.prototype, "highlighterOptions", {
        get: function () {
            return this.adapterOptions.prism;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PrismHighlighter.prototype, "id", {
        get: function () {
            return 'prismjs';
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PrismHighlighter.prototype, "enableCodeLineNumber", {
        get: function () {
            return this.adapterOptions.enableCodeLineNumber;
        },
        enumerable: false,
        configurable: true
    });
    PrismHighlighter.prototype.highlight = function (el) {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            var _b, preEl, codeEl;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, this.ensureResourcesLoaded()];
                    case 1:
                        _c.sent();
                        _b = (_a = this.resolveContainerElements(el)) !== null && _a !== void 0 ? _a : [], preEl = _b[0], codeEl = _b[1];
                        if (!preEl || !codeEl)
                            return [2 /*return*/];
                        if (this.adapterOptions.enableCodeLineNumber) {
                            preEl.classList.add('line-numbers');
                        }
                        else {
                            preEl.classList.remove('line-numbers');
                            codeEl.classList.remove('line-numbers');
                        }
                        this.tryApplyLang(codeEl);
                        this.setBodyClass('prismjs');
                        this.setEngineClassToken(this.id, preEl);
                        this.removeLinesHighlightedClassToken(preEl);
                        this.filterCodeContent(codeEl);
                        adaptSql(codeEl);
                        Prism.highlightElement(codeEl, false);
                        this.highlightLines(preEl);
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.highlightLines = function (preEl) {
        var _a, _b;
        var codeEl = preEl.querySelector('code');
        var linesToHighlight = this.resolveLinesToHighlight(codeEl) || this.resolveLinesToHighlight(preEl);
        if (!linesToHighlight)
            return [];
        var html = codeEl.innerHTML;
        var lineNumbersRowsHtml = (_b = (_a = codeEl.querySelector('.line-numbers-rows')) === null || _a === void 0 ? void 0 : _a.outerHTML) !== null && _b !== void 0 ? _b : '';
        if (lineNumbersRowsHtml) {
            html = html.replace(lineNumbersRowsHtml, '');
        }
        var lines = html.split('\n');
        linesToHighlight.forEach(function (lineNumber) {
            if (lineNumber < 0 || lineNumber >= lines.length)
                return;
            var lineContent = lines[lineNumber];
            lines[lineNumber] = "<span class=\"".concat(HighlightedLineToken, "\">").concat(lineContent, "</span>");
        });
        codeEl.innerHTML = lines.join('\n') + lineNumbersRowsHtml;
        preEl.classList.add(this.linesHighlightedClassToken);
        return linesToHighlight;
    };
    PrismHighlighter.prototype.ensureResourcesLoaded = function () {
        return __awaiter(this, void 0, void 0, function () {
            var err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 4, , 5]);
                        return [4 /*yield*/, this.loadPrismAsync()];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, Promise.all([this.loadPrismAutoLoader(), this.loadPrismLineNumberPluginScript()])];
                    case 2:
                        _a.sent();
                        return [4 /*yield*/, this.loadStyles([this._linkAttr])];
                    case 3:
                        _a.sent();
                        return [3 /*break*/, 5];
                    case 4:
                        err_1 = _a.sent();
                        console.error(err_1);
                        return [2 /*return*/];
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.setTheme = function (theme, attributes, isDarkTheme) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.setTheme.call(this, theme, attributes, isDarkTheme)];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.loadPrismLineNumberPluginStyle()];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismAsync = function () {
        return __awaiter(this, void 0, void 0, function () {
            var href;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _global.Prism = _global.Prism || {};
                        Prism.manual = true;
                        href = this.adapterOptions.prism.scriptPath;
                        return [4 /*yield*/, loadScript({
                                id: 'prismjs-script',
                                src: href,
                            })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismAutoLoader = function () {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            var loaded, href;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        loaded = !!((_a = _global.Prism.plugins) === null || _a === void 0 ? void 0 : _a.autoloader);
                        href = this.adapterOptions.prism.autoLoaderPluginPath;
                        if (!!loaded) return [3 /*break*/, 2];
                        return [4 /*yield*/, loadScript({
                                id: 'prismjs-autoloader-script',
                                src: href,
                            })];
                    case 1:
                        _b.sent();
                        _b.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismLineNumberPluginScript = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.enableCodeLineNumber)
                            return [2 /*return*/];
                        if (!this.adapterOptions.prism.lineNumberPluginPath) {
                            throw Error('lineNumberPluginPath not configured');
                        }
                        return [4 /*yield*/, loadScript({
                                id: 'prism-line-numbers-script',
                                src: this.adapterOptions.prism.lineNumberPluginPath,
                            })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismLineNumberPluginStyle = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!this.enableCodeLineNumber)
                    return [2 /*return*/];
                if (!this.adapterOptions.prism.lineNumberStylePath) {
                    throw Error('lineNumberStylePath not configured');
                }
                loadCss({
                    id: 'prism-line-numbers-style',
                    href: this.adapterOptions.prism.lineNumberStylePath,
                    beforeElementCreateCallback: function (el) {
                        return setAttributes(el, [
                            {
                                name: 'prismjs',
                                value: '',
                            },
                        ]);
                    },
                }).then();
                return [2 /*return*/];
            });
        });
    };
    return PrismHighlighter;
}(BaseHighlighter));
export { PrismHighlighter };

==> code-highlight-adapter-1.7.6.tgz: package/lib-esm/highlighters/prism-highlighter.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { BaseHighlighter } from './base-highlighter';
import { adaptSql, setAttributes } from './utils';
import { loadCss, loadScript } from '@cnblogs/load-script-css';
import { HighlightedLineToken } from './constants';
var _global = window;
/**
 * @public
 */
var PrismHighlighter = /** @class */ (function (_super) {
    __extends(PrismHighlighter, _super);
    function PrismHighlighter() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._linkAttr = {
            name: 'prismjs',
            value: '',
        };
        return _this;
    }
    Object.defineProperty(PrismHighlighter.prototype, "highlighterOptions", {
        get: function () {
            return this.adapterOptions.prism;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PrismHighlighter.prototype, "id", {
        get: function () {
            return 'prismjs';
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PrismHighlighter.prototype, "enableCodeLineNumber", {
        get: function () {
            return this.adapterOptions.enableCodeLineNumber;
        },
        enumerable: false,
        configurable: true
    });
    PrismHighlighter.prototype.highlight = function (el) {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            var _b, preEl, codeEl;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, this.ensureResourcesLoaded()];
                    case 1:
                        _c.sent();
                        _b = (_a = this.resolveContainerElements(el)) !== null && _a !== void 0 ? _a : [], preEl = _b[0], codeEl = _b[1];
                        if (!preEl || !codeEl)
                            return [2 /*return*/];
                        if (this.adapterOptions.enableCodeLineNumber) {
                            preEl.classList.add('line-numbers');
                        }
                        else {
                            preEl.classList.remove('line-numbers');
                            codeEl.classList.remove('line-numbers');
                        }
                        this.tryApplyLang(codeEl);
                        this.onHighlighting(this.id, preEl, codeEl);
                        this.filterCodeContent(codeEl);
                        adaptSql(codeEl);
                        Prism.highlightElement(codeEl, false);
                        this.highlightLines(preEl);
                        this.onHighlighted(this.id, preEl, codeEl);
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.highlightLines = function (preEl) {
        var _a, _b;
        var codeEl = preEl.querySelector('code');
        var linesToHighlight = this.resolveLinesToHighlight(codeEl) || this.resolveLinesToHighlight(preEl);
        if (!linesToHighlight)
            return [];
        var html = codeEl.innerHTML;
        var lineNumbersRowsHtml = (_b = (_a = codeEl.querySelector('.line-numbers-rows')) === null || _a === void 0 ? void 0 : _a.outerHTML) !== null && _b !== void 0 ? _b : '';
        if (lineNumbersRowsHtml) {
            html = html.replace(lineNumbersRowsHtml, '');
        }
        var lines = html.split('\n');
        linesToHighlight.forEach(function (lineNumber) {
            if (lineNumber < 0 || lineNumber >= lines.length)
                return;
            var lineContent = lines[lineNumber];
            lines[lineNumber] = "<span class=\"".concat(HighlightedLineToken, "\">").concat(lineContent, "</span>");
        });
        codeEl.innerHTML = lines.join('\n') + lineNumbersRowsHtml;
        preEl.classList.add(this.linesHighlightedClassToken);
        return linesToHighlight;
    };
    PrismHighlighter.prototype.ensureResourcesLoaded = function () {
        return __awaiter(this, void 0, void 0, function () {
            var err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 4, , 5]);
                        return [4 /*yield*/, this.loadPrismAsync()];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, Promise.all([this.loadPrismAutoLoader(), this.loadPrismLineNumberPluginScript()])];
                    case 2:
                        _a.sent();
                        return [4 /*yield*/, this.loadStyles([this._linkAttr])];
                    case 3:
                        _a.sent();
                        return [3 /*break*/, 5];
                    case 4:
                        err_1 = _a.sent();
                        console.error(err_1);
                        return [2 /*return*/];
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.setTheme = function (theme, attributes, isDarkTheme) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.setTheme.call(this, theme, attributes, isDarkTheme)
                            .catch(function (e) {
                            return console.warn("Failed to set code theme: \"".concat(theme, "\", engine: ").concat(_this.id, ", isDarkTheme: ").concat(isDarkTheme, "\n").concat(e));
                        })];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.loadPrismLineNumberPluginStyle()];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismAsync = function () {
        return __awaiter(this, void 0, void 0, function () {
            var href;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _global.Prism = _global.Prism || {};
                        Prism.manual = true;
                        href = this.adapterOptions.prism.scriptPath;
                        return [4 /*yield*/, loadScript({
                                id: 'prismjs-script',
                                src: href,
                            })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismAutoLoader = function () {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            var loaded, href;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        loaded = !!((_a = _global.Prism.plugins) === null || _a === void 0 ? void 0 : _a.autoloader);
                        href = this.adapterOptions.prism.autoLoaderPluginPath;
                        if (!!loaded) return [3 /*break*/, 2];
                        return [4 /*yield*/, loadScript({
                                id: 'prismjs-autoloader-script',
                                src: href,
                            })];
                    case 1:
                        _b.sent();
                        _b.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismLineNumberPluginScript = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.enableCodeLineNumber)
                            return [2 /*return*/];
                        if (!this.adapterOptions.prism.lineNumberPluginPath) {
                            throw Error('lineNumberPluginPath not configured');
                        }
                        return [4 /*yield*/, loadScript({
                                id: 'prism-line-numbers-script',
                                src: this.adapterOptions.prism.lineNumberPluginPath,
                            })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    PrismHighlighter.prototype.loadPrismLineNumberPluginStyle = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!this.enableCodeLineNumber)
                    return [2 /*return*/];
                if (!this.adapterOptions.prism.lineNumberStylePath) {
                    throw Error('lineNumberStylePath not configured');
                }
                loadCss({
                    id: 'prism-line-numbers-style',
                    href: this.adapterOptions.prism.lineNumberStylePath,
                    beforeElementCreateCallback: function (el) {
                        return setAttributes(el, [
                            {
                                name: 'prismjs',
                                value: '',
                            },
                        ]);
                    },
                }).then();
                return [2 /*return*/];
            });
        });
    };
    return PrismHighlighter;
}(BaseHighlighter));
export { PrismHighlighter };
